@@ -1188,7 +1188,7 @@ class Banmask(registry.SpaceSeparatedSetOfStrings):
         bhost = '*'
         if not options:
             options = supybot.protocols.irc.banmask.getSpecific(
-                channel, network)()
+                network, channel)()
         for option in options:
             if option == 'nick':
                 bnick = nick
@@ -1299,6 +1299,34 @@ registerGlobalValue(supybot.protocols.http, 'proxy',
     through.  The value should be of the form 'host:port'.""")))
 utils.web.proxy = supybot.protocols.http.proxy
 
+def defaultHttpHeaders(network, channel):
+    """Returns the default HTTP headers to use for this channel/network."""
+    headers = utils.web.baseDefaultHeaders.copy()
+    try:
+        language = supybot.protocols.http.requestLanguage.getSpecific(
+                network, channel)()
+    except registry.NonExistentRegistryEntry:
+        pass # Starting up; language will be set by HttpRequestLanguage later
+    else:
+        if language:
+            headers['Accept-Language'] = language
+        elif 'Accept-Language' in headers:
+            del headers['Accept-Language']
+    return headers
+
+class HttpRequestLanguage(registry.String):
+    """Must be a valid HTTP Accept-Language value."""
+    __slots__ = ()
+    def setValue(self, v):
+        super(HttpRequestLanguage, self).setValue(v)
+        utils.web.defaultHeaders = defaultHttpHeaders(None, None)
+
+registerChannelValue(supybot.protocols.http, 'requestLanguage',
+    HttpRequestLanguage('', _("""If set, the Accept-Language HTTP header will be set to this
+    value for requests. Useful for overriding the auto-detected language based on
+    the server's location.""")))
+
+
 ###
 # supybot.protocols.ssl
 ###
